==> gromacs_5.0.6.orig.tar.gz: gromacs-5.0.6/src/gromacs/gmxlib/md_logging.c <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team.
 * Copyright (c) 2012, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <stdarg.h>
#include "types/commrec.h"
#include "md_logging.h"


void md_print_info(const t_commrec *cr, FILE *fplog,
                   const char *fmt, ...)
{
    va_list ap;

    if (cr == NULL || SIMMASTER(cr))
    {
        va_start(ap, fmt);

        vfprintf(stderr, fmt, ap);

        va_end(ap);
    }
    if (fplog != NULL)
    {
        va_start(ap, fmt);

        vfprintf(fplog, fmt, ap);

        va_end(ap);
    }
}

void md_print_warn(const t_commrec *cr, FILE *fplog,
                   const char *fmt, ...)
{
    va_list ap;

    if (cr == NULL || SIMMASTER(cr))
    {
        va_start(ap, fmt);

        fprintf(stderr, "\n");
        vfprintf(stderr, fmt, ap);
        fprintf(stderr, "\n");

        va_end(ap);
    }
    if (fplog != NULL)
    {
        va_start(ap, fmt);

        fprintf(fplog, "\n");
        vfprintf(fplog, fmt, ap);
        fprintf(fplog, "\n");

        va_end(ap);
    }
}

==> gromacs_5.1.2.orig.tar.gz: gromacs-5.1.2/src/gromacs/gmxlib/md_logging.c <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team.
 * Copyright (c) 2012,2014, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
#include "gmxpre.h"

#include "gromacs/legacyheaders/md_logging.h"

#include <stdarg.h>
#include <stdio.h>

#include "gromacs/legacyheaders/types/commrec.h"


void md_print_info(const t_commrec *cr, FILE *fplog,
                   const char *fmt, ...)
{
    va_list ap;

    if (cr == NULL || SIMMASTER(cr))
    {
        va_start(ap, fmt);

        vfprintf(stderr, fmt, ap);

        va_end(ap);
    }
    if (fplog != NULL)
    {
        va_start(ap, fmt);

        vfprintf(fplog, fmt, ap);

        va_end(ap);
    }
}

void md_print_warn(const t_commrec *cr, FILE *fplog,
                   const char *fmt, ...)
{
    va_list ap;

    if (cr == NULL || SIMMASTER(cr))
    {
        va_start(ap, fmt);

        fprintf(stderr, "\n");
        vfprintf(stderr, fmt, ap);
        fprintf(stderr, "\n");

        va_end(ap);
    }
    if (fplog != NULL)
    {
        va_start(ap, fmt);

        fprintf(fplog, "\n");
        vfprintf(fplog, fmt, ap);
        fprintf(fplog, "\n");

        va_end(ap);
    }
}
